@@ -1245,8 +1245,9 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
         """ applies a function to the data and returns it as a field
         
         Args:
-            func (callable):
-                The (vectorized) function being applied to the data.
+            func (callable or str):
+                The (vectorized) function being applied to the data or the name
+                of an operator that is defined for the grid of this field.
             out (FieldBase, optional):
                 Optional field into which the data is written
             label (str, optional):
@@ -1545,7 +1546,7 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
         ax.set_title(data.get('title', self.label))
         
         if colorbar:
-            from ..tools.misc import add_scaled_colorbar
+            from ..tools.plotting import add_scaled_colorbar
             add_scaled_colorbar(axes_image, ax=ax)
                 
         parameters = {'scalar': scalar, 'transpose': transpose}
