@@ -276,6 +276,22 @@ def test_div_grad_quadratic():
     np.testing.assert_allclose(divgrad.data, np.full(32, 2.))
     
     
+
+@pytest.mark.parametrize('dim', [1, 2, 3])
+def test_gradient_squared(dim):
+    """ compare gradient squared operator """
+    grid = CartesianGrid([[0, 2*np.pi]] * dim,
+                         shape=np.random.randint(30, 35, dim),
+                         periodic=np.random.choice([False, True], dim))
+    field = ScalarField.random_harmonic(grid, modes=1)
+    s1 = field.gradient('natural').to_scalar('squared_sum')
+    s2 = field.gradient_squared('natural', central=True)
+    np.testing.assert_allclose(s1.data, s2.data, rtol=0.1, atol=0.1)
+    s3 = field.gradient_squared('natural', central=False)
+    np.testing.assert_allclose(s1.data, s3.data, rtol=0.2, atol=0.2)
+    assert not np.array_equal(s2.data, s3.data)
+        
+    
     
 def test_rect_div_grad():
     """ compare div grad to laplacian """
