@@ -136,6 +136,19 @@ def test_grid_laplace():
      
      
      
+def test_gradient_squared():
+    """ compare gradient squared operator """
+    grid = CylindricalGrid(2*np.pi, [0, 2*np.pi], 64)
+    field = ScalarField.random_harmonic(grid, modes=1)
+    s1 = field.gradient('natural').to_scalar('squared_sum')
+    s2 = field.gradient_squared('natural', central=True)
+    np.testing.assert_allclose(s1.data, s2.data, rtol=0.2, atol=0.2)
+    s3 = field.gradient_squared('natural', central=False)
+    np.testing.assert_allclose(s1.data, s3.data, rtol=0.2, atol=0.2)
+    assert not np.array_equal(s2.data, s3.data)
+    
+     
+     
 def test_grid_div_grad():
     """ compare div grad to laplacian """
     grid = CylindricalGrid(2*np.pi, (0, 2*np.pi), (16, 16), periodic_z=True)
