@@ -8,7 +8,7 @@ import numpy as np
 import pytest
 
 from .. import UnitGrid, CartesianGrid
-from ..boundaries import Boundaries, PeriodicityError
+from ..boundaries import Boundaries, PeriodicityError, DomainError
 
 
 
@@ -79,15 +79,22 @@ def test_unit_grid_1d(periodic):
     assert grid.dim == 1
     assert grid.volume == 8
 
-    normalize = grid.normalize_point
-    if periodic:
-        np.testing.assert_allclose(normalize(-1e-10), 8 - 1e-10)
-        np.testing.assert_allclose(normalize(1e-10), 1e-10)
-        np.testing.assert_allclose(normalize(8 - 1e-10), 8 - 1e-10)
-        np.testing.assert_allclose(normalize(8 + 1e-10), 1e-10)
-    else:
-        for x in [-1e-10, 1e-10, 8 - 1e-10, 8 + 1e-10]:
-            np.testing.assert_allclose(normalize(x), x)
+    norm_numba = grid.make_normalize_point_compiled()
+    
+    def norm_numba_wrap(x):
+        y = np.array([x])
+        norm_numba(y)
+        return y
+    
+    for normalize in [grid.normalize_point, norm_numba_wrap]:
+        if periodic:
+            np.testing.assert_allclose(normalize(-1e-10), 8 - 1e-10)
+            np.testing.assert_allclose(normalize(1e-10), 1e-10)
+            np.testing.assert_allclose(normalize(8 - 1e-10), 8 - 1e-10)
+            np.testing.assert_allclose(normalize(8 + 1e-10), 1e-10)
+        else:
+            for x in [-1e-10, 1e-10, 8 - 1e-10, 8 + 1e-10]:
+                np.testing.assert_allclose(normalize(x), x)
 
     grid = UnitGrid(8, periodic=periodic)
     
@@ -370,6 +377,15 @@ def test_interpolate_1d():
     
     assert intp(np.zeros(2), np.zeros(1)) == pytest.approx(1)
     assert intp(np.zeros(2), np.ones(1)) == pytest.approx(0)
+    with pytest.raises(DomainError):
+        intp(np.zeros(2), np.array([-1]))
+    with pytest.raises(DomainError):
+        intp(np.zeros(2), np.array([3]))
+    
+    grid_per = UnitGrid(2, periodic=True)
+    intp = grid_per.make_interpolator_compiled(bc='natural')
+    for pos in [-1, 0, 1, 2, 3]:
+        assert intp(np.arange(2), np.array([pos])) == pytest.approx(0.5)
 
 
 
