@@ -22,8 +22,15 @@ def test_memory_storage():
     s2.start_writing(sf)
     s2.append(np.array([1]), 0)
     s2.append(np.array([3]), 1)
+
+    # test from_fields
+    s3 = MemoryStorage.from_fields(s1.times, [s1[0], s1[1]])
+    assert s3.times == s1.times
+    np.testing.assert_allclose(s3.data, s1.data)
     
+    # test from_collection
     s3 = MemoryStorage.from_collection([s1, s2])
+    assert s3.times == s1.times
     np.testing.assert_allclose(np.ravel(s3.data), np.arange(4))
 
 
@@ -42,6 +49,7 @@ def test_field_type_guessing():
         s._field = None
         s.info = {}
         
+        assert not s.has_collection
         assert len(s) == 2
         assert s[0] == field
         
@@ -50,6 +58,8 @@ def test_field_type_guessing():
     s.start_writing(field)
     s.append(field.data, 0)
     
+    assert s.has_collection
+    
     # delete information
     s._field = None
     s.info = {}
